desk package — Dusty-Evolved-Star-Kit 1.4.7 documentation

# desk package

## Submodules

## desk.config module

Steve Goldman Space Telescope Science Institute May 17, 2018 sgoldman@stsci.edu

This script is for plotting the outputs of the sed_fitting script.

## desk.get_remote_models module

`desk.get_remote_models.` `get_models`(model_grid_name)

## desk.parameter_ranges module

`desk.parameter_ranges.` `create_par`()

## desk.plotting_seds module

`desk.plotting_seds.` `create_fig`()
  Returns

    Runs plotting script

`desk.plotting_seds.` `single_fig`()
  Returns

    Runs plotting script

## desk.sed_fit module

`desk.sed_fit.` `check_models`(model_grid, full_path)

`desk.sed_fit.` `find_closest`(target_wave, model_wave)
  Parameters

    - target_wave – Target wavelength in um

    - model_wave – model wavelength in um

  Returns

    a 1-D array of the closest data wavelength values, to the model wavelength values

`desk.sed_fit.` `fit`(source='default', distance=50, grid='Zubko-Crich-bb')
  Parameters

    - source – Name of target in array of strings (or one string)

    - distance – distance to source(s) in kiloparsecs

    - grid – Name of model grid

  Returns

`desk.sed_fit.` `fit_norm`(data, norm_model)
  Parameters

    - data – input data in tuple of x and y arrays

    - norm_model – closest wavelength values to data in 1-D array (from trim)

  Returns

    trimmed model in 2 column np.array

`desk.sed_fit.` `get_data`(filename)
  Parameters

    filename – filename of input data. Should be csv with Column 0: wavelength in um and Col 1: flux in Jy

  Returns

    two arrays of wavelength (x) and flux (y) in unit specified in config.py

`desk.sed_fit.` `get_model`(grid_name, teff_new, tinner_new, tau_new)

`desk.sed_fit.` `grids`()

`desk.sed_fit.` `least2`(data, model_l2)

`desk.sed_fit.` `make_output_files_dusty`()

`desk.sed_fit.` `make_output_files_grams`()

`desk.sed_fit.` `sed_fitting`(target)

`desk.sed_fit.` `trim`(data, model_trim)
  Parameters

    - data – input data in tuple of x and y arrays

    - model_trim – input model

  Returns

    trims motimedel to wavelength range of data

## Module contents

This packages contains python packages that are bundled with the package but are external to it, and hence are developed in a separate source tree. Note that this package is distinct from the /cextern directory of the source code distribution, as that directory only contains C extension code.